@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
-import six
 
+import agate.csv_py3 as csv
 from agate.aggregations import *
 from agate.columns import Column
 from agate.computations import *
@@ -17,8 +17,3 @@ from agate.testcase import AgateTestCase
 from agate.type_tester import TypeTester
 from agate.utils import *
 from agate.warns import DuplicateColumnWarning, NullCalculationWarning, warn_duplicate_column, warn_null_calculation
-
-if six.PY2:  # pragma: no cover
-    import agate.csv_py2 as csv
-else:
-    import agate.csv_py3 as csv
